# Generated by Django 4.2.23 on 2025-06-29 17:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('eveuniverse', '0010_alter_eveindustryactivityduration_eve_type_and_more'),
        ('greenlight', '0003_remove_greenlightconfig_staging_systems_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='WebHook',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=150)),
                ('webhook_url', models.CharField(max_length=500)),
            ],
            options={
                'verbose_name': 'Webhook',
                'verbose_name_plural': 'Webhooks',
            },
        ),
        migrations.CreateModel(
            name='GreenlightConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='default', max_length=100, unique=True)),
                ('green_message', models.TextField(default='🟢 **GREEN ALERT!** All clear.')),
                ('yellow_message', models.TextField(default='🟡 **YELLOW ALERT!** Be ready.')),
                ('red_message', models.TextField(default='🔴 **RED ALERT!** Action needed!')),
                ('staging_systems', models.ManyToManyField(blank=True, help_text='Staging systems of umbrella.', to='eveuniverse.evesolarsystem')),
            ],
        ),
    ]
