# Generated by Django 4.2.23 on 2025-07-01 14:04

from django.db import migrations, models

def create_default_discord_config(apps, schema_editor):
    DiscordMessageConfig = apps.get_model("greenlight", "DiscordMessageConfig")
    if not DiscordMessageConfig.objects.exists():
        DiscordMessageConfig.objects.create(name="default")

class Migration(migrations.Migration):

    dependencies = [
        ('greenlight', '0009_discordmessageconfig'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='doctrine_group',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='doctrine_ping',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='green_group',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='green_ping',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='red_group',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='red_ping',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='yellow_group',
        ),
        migrations.RemoveField(
            model_name='discordmessageconfig',
            name='yellow_ping',
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='doctrine_ping_target',
            field=models.CharField(blank=True, help_text='Select @everyone, @here, or a group name from AllianceAuth.', max_length=100),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='green_ping_target',
            field=models.CharField(blank=True, help_text='Select @everyone, @here, or a group name from AllianceAuth.', max_length=100),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='red_ping_target',
            field=models.CharField(blank=True, help_text='Select @everyone, @here, or a group name from AllianceAuth.', max_length=100),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='yellow_ping_target',
            field=models.CharField(blank=True, help_text='Select @everyone, @here, or a group name from AllianceAuth.', max_length=100),
        ),
    ]
