# Generated by Django 4.2.23 on 2025-07-01 14:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('greenlight', '0010_remove_discordmessageconfig_doctrine_group_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='discordmessageconfig',
            name='doctrine_gif_url',
            field=models.URLField(blank=True),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='green_gif_url',
            field=models.URLField(blank=True, help_text='Optional GIF for green status'),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='red_gif_url',
            field=models.URLField(blank=True),
        ),
        migrations.AddField(
            model_name='discordmessageconfig',
            name='yellow_gif_url',
            field=models.URLField(blank=True),
        ),
    ]
