# Generated by Django 4.2.23 on 2025-06-30 14:22

from django.db import migrations

def set_default_fleet_status(apps, schema_editor):
    GreenlightConfig = apps.get_model('greenlight', 'GreenlightConfig')
    GreenlightConfig.objects.filter(fleet_status__isnull=True).update(fleet_status='green')


class Migration(migrations.Migration):

    dependencies = [
        ('greenlight', '0007_remove_greenlightconfig_doctrine_id_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='greenlightconfig',
            name='current_status',
        ),
    ]
