# Generated by Django 4.2.23 on 2025-06-29 21:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('greenlight', '0005_create_default_config'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='general',
            options={'default_permissions': (), 'managed': False, 'permissions': (('basic_access', 'Can access this app'), ('can_manage_fleets', 'Can manage fleets'))},
        ),
        migrations.AlterModelOptions(
            name='webhook',
            options={},
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='current_status',
            field=models.CharField(choices=[('green', '🟢 Green - All clear'), ('yellow', '🟡 Yellow - Be ready'), ('red', '🔴 Red - Action needed')], default='green', max_length=10),
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='doctrine_id',
            field=models.PositiveIntegerField(blank=True, help_text='ID of doctrine in AllianceAuth Fittings module', null=True),
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='fc_character_name',
            field=models.CharField(blank=True, help_text='Name of current fleet commander shown to members', max_length=255),
        ),
    ]
