# Generated by Django 4.2.23 on 2025-06-30 11:17

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('eveonline', '0017_alliance_and_corp_names_are_not_unique'),
        ('fittings', '0016_remove_dogmaattribute_type_remove_dogmaeffect_type_and_more'),
        ('greenlight', '0006_alter_general_options_alter_webhook_options_and_more'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='greenlightconfig',
            name='doctrine_id',
        ),
        migrations.RemoveField(
            model_name='greenlightconfig',
            name='fc_character_name',
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='current_doctrine',
            field=models.ForeignKey(blank=True, help_text='Doctrine for current fleet', null=True, on_delete=django.db.models.deletion.SET_NULL, to='fittings.doctrine'),
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='current_fc',
            field=models.ForeignKey(blank=True, help_text='Currently assigned FC', null=True, on_delete=django.db.models.deletion.SET_NULL, to='eveonline.evecharacter'),
        ),
        migrations.AddField(
            model_name='greenlightconfig',
            name='fleet_status',
            field=models.CharField(choices=[('green', 'Green'), ('yellow', 'Yellow'), ('red', 'Red')], default='green', max_length=10),
        ),
    ]
