# Generated by Django 4.2.23 on 2025-07-01 13:51

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('auth', '0012_alter_user_first_name_max_length'),
        ('greenlight', '0008_remove_greenlightconfig_current_status'),
    ]

    operations = [
        migrations.CreateModel(
            name='DiscordMessageConfig',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(default='default', max_length=100, unique=True)),
                ('green_message', models.TextField(default='🟢 **GREEN ALERT!** All clear.')),
                ('green_ping', models.CharField(blank=True, choices=[('', 'None'), ('@everyone', '@everyone'), ('@here', '@here')], max_length=100)),
                ('yellow_message', models.TextField(default='🟡 **YELLOW ALERT!** Be ready.')),
                ('yellow_ping', models.CharField(blank=True, choices=[('', 'None'), ('@everyone', '@everyone'), ('@here', '@here')], max_length=100)),
                ('red_message', models.TextField(default='🔴 **RED ALERT!** Action needed!')),
                ('red_ping', models.CharField(blank=True, choices=[('', 'None'), ('@everyone', '@everyone'), ('@here', '@here')], max_length=100)),
                ('doctrine_change_message', models.TextField(default='🛠️ **Fleet composition updated.**')),
                ('doctrine_ping', models.CharField(blank=True, choices=[('', 'None'), ('@everyone', '@everyone'), ('@here', '@here')], max_length=100)),
                ('doctrine_group', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='auth.group')),
                ('green_group', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='auth.group')),
                ('red_group', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='auth.group')),
                ('yellow_group', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to='auth.group')),
            ],
        ),
    ]
