# Generated by Django 4.2.23 on 2025-06-29 17:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('greenlight', '0002_webhook_greenlightconfig'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='greenlightconfig',
            name='staging_systems',
        ),
        migrations.DeleteModel(
            name='WebHook',
        ),
        migrations.DeleteModel(
            name='GreenlightConfig',
        ),
    ]
